/*
**
**	$Id: App.cpp,v 1.1 1998/04/10 15:39:13 bobak Exp bobak $
**	$Revision: 1.1 $
**	$Filename: App.cpp $
**	$Date: 1998/04/10 15:39:13 $
**
**	Author: Andreas F. Bobak (bobak@abstrakt.ch)
**
**	Copyright (C) 1998 by Abstrakt SEC, Andreas F. Bobak.
**
**	This is free software; you can redistribute it and / or modify it 
**	under the terms of the GNU General Public License as published by
**	the Free Software Foundation; either version 2 of the License, or
**	(at your option) any later version.
**
**	This software is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY;  without even the  implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
**	General Public License for more details.
**
**	You should have received a copy of the GNU General Public License
**	along with this software; if not, write to the Free Software
**	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
**	USA.
**
*/
#include "App.h"
#include "Connection.h"
#include "WndLogin.h"

#define FLASHPORT  (5400)    /* Offset to listen for `flash' commands */
#define CLIENTPORT (5500)    /* Offset to listen for reverse connections */
#define SERVERPORT (5900)    /* Offset to server for regular connections */

// this is to get the application to run
int main( void ) { App app; app.Run(); return 0; }

/*****************************************************************************
**	App
*/

/****
**	@purpose	Constructs a new App instance.
*/
App::App( void )
	: BApplication("application/x-vnd.Abstrakt-VNCviewer"),
	  myAppName("VNCviewer"),
	  myConnection(NULL),
	  myAddCopyRect(true),
	  myAddHextile(false),
	  myAddCoRRE(true),
	  myAddRRE(false),
	  myIsBatchMode(false),
	  myIsLittleEndian(true),
	  myIsListenSpecified(false),
	  myIsShareDesktop(false),
	  myIsUse8bit(false),
	  myExplicitEnc(0)
{
	memset( myExplicitEncodings, 0, sizeof(myExplicitEncodings) );
	WndLogin::Create();
}

/****
**	@purpose	Destroys an existing App instance.
*/
App::~App( void )
{
}


/****
**	@purpose	Shows a simple BeAlert.
**	@param		body	Text to show.
**	@param		arg		passed to sprintf.
*/
void
App::Alert( const char* body, const char* arg )
{
	char buf[256];
	sprintf( buf, body, arg );
	BAlert* alert = new BAlert( App::GetApp()->GetName(), buf, "OK" );
	alert->Go();
}

/****
**	@purpose	See the BeBook.
**	@param		msg		A pointer to the received message.
*/
void
App::MessageReceived( BMessage* msg )
{
	switch (msg->what)
	{
	case msg_connect:
	  {
		char	*host, *passwd;
		char	hostname[256];
		int		port;

		msg->FindString( "hostname", &host );
		msg->FindString( "password", &passwd );

		if (sscanf( host, "%[^:]:%d", hostname, &port ) == 2)
		{
			if (port < 100)
				port += SERVERPORT;

			myConnection = new Connection();
			if (myConnection->Connect( hostname, port, passwd ))
			{
				// OK
			}
			else
			{
				delete myConnection;
				myConnection = NULL;
				PostMessage( B_QUIT_REQUESTED );
			}
		}
		else
		{
			char	buf[256];
			sprintf( buf, "'%s' doesn't specify a hostname + port number.\n", host );
			BAlert* alert = new BAlert( App::GetName(), buf, "OK" );
			alert->Go();
			PostMessage( B_QUIT_REQUESTED );
		}
		break;
	  }

	case msg_window_closed:
		if (myConnection != NULL)
			myConnection->PostMessage( B_QUIT_REQUESTED );
		be_app->PostMessage( B_QUIT_REQUESTED );
		break;

	default:
		BApplication::MessageReceived( msg );
		break;
	}
}
